@@ -142,7 +142,7 @@ class Client:
         death_history = []
         #recovery_history = []
                 
-        name = historical_stats["standardizedCountryName"]
+        name = historical_stats["country"]
 
         if not historical_stats["timeline"]["cases"]:
             raise APIerror('Couldn\'t get stats for given country')
